@@ -1013,6 +1013,20 @@ class AppHandler(object):
                 self.config, **kwargs)
         return self.problem_report_handler
 
+    def get_tailbone_handler(self, **kwargs):
+        """
+        Get the configured "tailbone" handler.
+
+        :returns: The :class:`~tailbone:tailbone.handler.TailboneHandler`
+           instance for the app.
+        """
+        if not hasattr(self, 'tailbone_handler'):
+            spec = self.config.get('tailbone', 'handler',
+                                   default='tailbone.handler:TailboneHandler')
+            Handler = self.load_object(spec)
+            self.tailbone_handler = Handler(self.config)
+        return self.tailbone_handler
+
     def get_trainwreck_handler(self, **kwargs):
         """
         Get the configured "trainwreck" handler.
@@ -1170,17 +1184,21 @@ class AppHandler(object):
                 os.mkdir(path)
 
     def render_mako_template(self, template_path, context,
-                             output_path=None, **kwargs):
+                             template=None, output_path=None, **kwargs):
         """
         Convenience method to render any (specified) Mako template.
         """
-        output = Template(filename=template_path).render(**context)
+        if not template:
+            template = Template(filename=template_path)
+        output = template.render(**context)
         if output_path:
             with open(output_path, 'wt') as f:
                 f.write(output)
         return output
 
-    def make_config_file(self, file_type, output_path, template_path=None,
+    def make_config_file(self, file_type, output_path,
+                         template=None,
+                         template_path=None,
                          **kwargs):
         """
         Write a new config file of given type to specified location.
@@ -1194,6 +1212,8 @@ class AppHandler(object):
            written.  If this is a folder, then the filename is deduced
            from the ``file_type``.
 
+        :param template: Optional reference to a Mako template instance.
+
         :param template_path: Optional path to config file template to
            use.  If not specified, it will be looked up dynamically
            based on the ``file_type``.  Note that the first template
@@ -1207,7 +1227,7 @@ class AppHandler(object):
         :returns: Final path to which new config file was written.
         """
         # lookup template if not specified
-        if not template_path:
+        if not template and not template_path:
             template_path = self.find_config_template(file_type)
             if not template_path:
                 raise RuntimeError("config template not found for type: {}".format(file_type))
@@ -1217,7 +1237,7 @@ class AppHandler(object):
             output_path = os.path.join(output_path, '{}.conf'.format(file_type))
 
         # just copy file as-is unless it's mako
-        if not template_path.endswith('.mako'):
+        if not template and not template_path.endswith('.mako'):
             shutil.copy(template_path, output_path)
             return output_path
 
@@ -1236,6 +1256,7 @@ class AppHandler(object):
         }
         context.update(kwargs)
         self.render_mako_template(template_path, context,
+                                  template=template,
                                   output_path=output_path)
         return output_path
 
