@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -438,6 +438,89 @@ class Subcommand(object):
         """
         raise NotImplementedError
 
+    def require_prompt_toolkit(self):
+        try:
+            import prompt_toolkit
+        except ImportError:
+            value = input("\nprompt_toolkit is not installed.  shall i install it? [Yn] ")
+            value = value.strip()
+            if value and not self.config.parse_bool(value):
+                self.stderr.write("prompt_toolkit is required; aborting\n")
+                sys.exit(1)
+
+            subprocess.check_call(['pip', 'install', 'prompt_toolkit'])
+
+    def require_rich(self):
+        try:
+            import rich
+        except ImportError:
+            value = input("\nrich is not installed.  shall i install it? [Yn] ")
+            value = value.strip()
+            if value and not self.config.parse_bool(value):
+                self.stderr.write("rich is required; aborting\n")
+                sys.exit(1)
+
+            subprocess.check_call(['pip', 'install', 'rich'])
+
+    def rprint(self, *args, **kwargs):
+        self.require_rich()
+
+        # TODO: this could look different once python2 is out of the
+        # picture; but must avoid `print` keyword for python2
+        import rich
+        rprint = getattr(rich, 'print')
+        return rprint(*args, **kwargs)
+
+    def basic_prompt(self, info, default=None, is_password=False, is_bool=False,
+                     required=False):
+        self.require_prompt_toolkit()
+
+        from prompt_toolkit import prompt
+        from prompt_toolkit.styles import Style
+
+        # message formatting styles
+        style = Style.from_dict({
+            '': '',
+            'bold': 'bold',
+        })
+
+        # build prompt message
+        message = [
+            ('', '\n'),
+            ('class:bold', info),
+        ]
+        if default is not None:
+            if is_bool:
+                message.append(('', ' [{}]: '.format('Y' if default else 'N')))
+            else:
+                message.append(('', ' [{}]: '.format(default)))
+        else:
+            message.append(('', ': '))
+
+        # prompt user for input
+        try:
+            text = prompt(message, style=style, is_password=is_password)
+        except (KeyboardInterrupt, EOFError):
+            self.rprint("\n\t[bold yellow]operation canceled by user[/bold yellow]\n",
+                        file=self.stderr)
+            sys.exit(2)
+
+        if is_bool:
+            if text == '':
+                return default
+            elif text.upper() == 'Y':
+                return True
+            elif text.upper() == 'N':
+                return False
+            self.rprint("\n\t[bold yellow]ambiguous, please try again[/bold yellow]\n")
+            return self.basic_prompt(info, default, is_bool=True)
+
+        if required and not text and not default:
+            return self.basic_prompt(info, default, is_password=is_password,
+                                     required=True)
+
+        return text or default
+
 
 class CheckDatabase(Subcommand):
     """
@@ -1174,6 +1257,13 @@ class Upgrade(Subcommand):
                             "will be read from the database.  If such an upgrade is not "
                             "found or is otherwise invalid (e.g. already executed), "
                             "the command will fail.")
+
+        parser.add_argument('--keep-exit-code', action='store_true',
+                            help="Exit with same return code as subprocess.  If "
+                            "this is not specified, this command will normally "
+                            "exit with code 0 regardless of what happens with "
+                            "the subprocess.  (only applicable with --execute)")
+
         parser.add_argument('--dry-run', action='store_true',
                             help="Go through the full motions and allow logging etc. to "
                             "occur, but rollback (abort) the transaction at the end.")
@@ -1247,6 +1337,10 @@ class Upgrade(Subcommand):
             log.info("transaction was committed")
         session.close()
 
+        if (args.execute and not args.dry_run
+            and args.keep_exit_code and upgrade.exit_code):
+            sys.exit(upgrade.exit_code)
+
 
 def main(*args):
     """
