@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -546,6 +546,13 @@ class RattailConfig(object):
         """
         return self.getbool('rattail', 'production', default=False)
 
+    def running_from_source(self):
+        """
+        Returns boolean indicating whether the app is running from
+        source, as opposed to official release.
+        """
+        return self.getbool('rattail', 'running_from_source', default=False)
+
     def demo(self):
         """
         Returns boolean indicating whether the app is running in demo mode
