@@ -107,7 +107,10 @@ class KeheInvoiceParser(InvoiceParser):
         if version == 1:
             return datetime.datetime.strptime(data['Invoice Date'], '%Y-%m-%d').date()
         elif version in (2, 3):
-            return datetime.datetime.strptime(data['InvoiceDate'], '%m/%d/%Y %I:%M:%S %p').date()
+            try:
+                return datetime.datetime.strptime(data['InvoiceDate'], '%m/%d/%Y %I:%M:%S %p').date()
+            except ValueError:
+                return datetime.datetime.strptime(data['InvoiceDate'], '%m/%d/%Y').date()
         elif version == 4:
             return datetime.datetime.strptime(data['InvoiceDate'], '%m/%d/%Y').date()
 
