@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -112,23 +112,13 @@ class UnfiInvoiceParser(InvoiceParser):
         # order parser (in ``rattail_livnat.scangenius``).  I wonder if we can
         # abstract it into a generic yet custom CSV parser...?
 
-        # Calculate the offset of the details section, based on the sum
-        # character length of the header section (which is 2 lines long).
-        if six.PY3:
-            reader = UnicodeReader(csv_file)
-        else: # PY2
-            reader = UnicodeReader(csv_file, encoding='latin_1')
-
         offset = 0
         for line, row in enumerate(csv_file, 1):
             offset += len(row)
             if line == 2:
                 break
 
-        # TODO: presumably the 2 bytes difference here, is because we use
-        # "text" mode under PY3 vs. "bytes" mode for PY2?  this seems
-        # pretty fragile and likely will need improvements?
-        if six.PY3:
-            offset += 2
+        # account for newline chars
+        offset += 2 * (len(csv_file.newlines) - 1)
 
         return offset
