@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -30,7 +30,6 @@ import re
 import logging
 
 from rattail.config import ConfigProfile
-from rattail.util import load_object
 from rattail.exceptions import ConfigurationError
 
 from rattail.datasync.watchers import NullWatcher
@@ -55,23 +54,55 @@ class DataSyncProfile(ConfigProfile):
         super(DataSyncProfile, self).__init__(*args, **kwargs)
 
         self.watcher_spec = self._config_string('watcher')
+
         if self.watcher_spec == 'null':
             self.watcher = NullWatcher(self.config, self.key)
+            self.watcher_kwargs = {}
+
         else:
+            kwargs = {}
+
+            # additional watcher kwargs will be read *directly* from
+            # either the config file, or DB settings table
+            handler = self.app.get_datasync_handler()
+            if handler.should_use_profile_settings():
+
+                # DB settings it is
+                model = self.model
+                with self.app.short_session() as s:
+                    settings = s.query(model.Setting)\
+                                .filter(model.Setting.name.like('rattail.datasync.{}.watcher.kwarg.%'.format(self.key)))\
+                                .all()
+                    for setting in settings:
+                        name = setting.name.split('watcher.kwarg.')[1]
+                        kwargs[name] = setting.value
+
+            else: # config file
+
+                pattern = re.compile(r'^{}\.watcher\.kwarg\.(?P<keyword>\w+)$'.format(self.key))
+                # TODO: this should not be referencing the config parser directly?
+                # (but we have no other way yet, to know which options are defined)
+                # (we should at least allow config to be defined in DB Settings)
+                # (however that should be optional, since some may not have a DB)
+                if self.config.parser.has_section(self.section):
+                    for option in self.config.parser.options(self.section):
+                        match = pattern.match(option)
+                        if match:
+                            keyword = match.group('keyword')
+                            kwargs[keyword] = self.config.get(self.section, option)
+
+            # only capture "explicitly configured" watcher kwargs..
+            # (nb. this is used for configuration of the kwargs)
+            self.watcher_kwargs = dict(kwargs)
+
+            # ..whereas in practice we also add one for the dbkey
             dbkey = self._config_string('watcher.db', default='default')
-            kwargs = {'dbkey': dbkey}
-            pattern = re.compile(r'^{}\.watcher\.kwarg\.(?P<keyword>\w+)$'.format(self.key))
-            # TODO: this should not be referencing the config parser directly?
-            # (but we have no other way yet, to know which options are defined)
-            # (we should at least allow config to be defined in DB Settings)
-            # (however that should be optional, since some may not have a DB)
-            if self.config.parser.has_section(self.section):
-                for option in self.config.parser.options(self.section):
-                    match = pattern.match(option)
-                    if match:
-                        keyword = match.group('keyword')
-                        kwargs[keyword] = self.config.get(self.section, option)
-            self.watcher = load_object(self.watcher_spec)(self.config, self.key, **kwargs)
+            kwargs['dbkey'] = dbkey
+
+            # make the watcher
+            factory = self.app.load_object(self.watcher_spec)
+            self.watcher = factory(self.config, self.key, **kwargs)
+
         self.watcher.delay = self._config_int('watcher.delay', default=self.watcher.delay)
         self.watcher.retry_attempts = self._config_int('watcher.retry_attempts', default=self.watcher.retry_attempts)
         self.watcher.retry_delay = self._config_int('watcher.retry_delay', default=self.watcher.retry_delay)
@@ -101,9 +132,10 @@ class DataSyncProfile(ConfigProfile):
                                         default='default')
             runas = self._config_string('consumer.{}.runas'.format(key))
             try:
-                consumer = load_object(consumer_spec)(self.config, key, dbkey=dbkey,
-                                                      runas=runas or default_runas,
-                                                      watcher=self.watcher)
+                factory = self.app.load_object(consumer_spec)
+                consumer = factory(self.config, key, dbkey=dbkey,
+                                   runas=runas or default_runas,
+                                   watcher=self.watcher)
             except:
                 log.debug("failed to load '%s' consumer for '%s' profile",
                           key, self.key, exc_info=True)
