@@ -37,7 +37,7 @@ def get_setting(session, name):
     """
     warnings.warn("function is deprecated, please use "
                   "AppHandler.get_setting() instead",
-                  DeprecationWarning)
+                  DeprecationWarning, stacklevel=2)
 
     local_session = False
     if session is None:
@@ -56,7 +56,7 @@ def save_setting(session, name, value):
     """
     warnings.warn("function is deprecated, please use "
                   "AppHandler.save_setting() instead",
-                  DeprecationWarning)
+                  DeprecationWarning, stacklevel=2)
 
     local_session = False
     if session is None:
