@@ -33,6 +33,7 @@ import warnings
 
 import sqlalchemy as sa
 from sqlalchemy import orm
+from sqlalchemy.ext.associationproxy import ASSOCIATION_PROXY
 
 # TODO: Deprecate/remove these imports.
 from rattail.db.config import engine_from_config, get_engines, get_default_engine, configure_session
@@ -121,6 +122,64 @@ class short_session(object):
             self.session = None
 
 
+def get_fieldnames(config, obj, columns=True, proxies=True,
+                   relations=False):
+    """
+    Produce a simple list of fieldnames for the given class,
+    reflecting its table columns as well as any association proxies,
+    and optionally, relationships.
+
+    :param obj: Either a class or instance of a class, which derives
+       from the base model class.
+
+    :param columns: Whether or not to include simple columns.
+
+    :param relations: Whether or not to include fields which represent
+       relationships to other models.  If ``False`` (the default) then
+       only "simple" fields will be included.
+
+    :param proxies: Whether or not to include association proxy fields.
+    """
+    if isinstance(obj, type):
+        cls = obj
+    else:
+        cls = obj.__class__
+
+    mapper = orm.class_mapper(cls)
+    fields = []
+
+    # columns + relations
+    prop_classes = []
+    if columns:
+        prop_classes.append(orm.ColumnProperty)
+    if relations:
+        prop_classes.append(orm.RelationshipProperty)
+    if prop_classes:
+        prop_classes = tuple(prop_classes)
+        fields.extend([prop.key for prop in mapper.iterate_properties
+                       if isinstance(prop, prop_classes)
+                       and not prop.key.startswith('_')
+                       and prop.key != 'versions'])
+
+    # proxies
+    if proxies:
+        for key, desc in sa.inspect(cls).all_orm_descriptors.items():
+            if desc.extension_type == ASSOCIATION_PROXY:
+
+                # must avoid association proxies which in turn use
+                # relationships, unless those are wanted by caller
+                if not relations:
+                    # TODO: this probably needs help, i stumbled thru it..
+                    prop = sa.inspect(desc.for_class(cls).target_class)\
+                             .get_property(desc.value_attr)
+                    if isinstance(prop, orm.RelationshipProperty):
+                        continue
+
+                fields.append(key)
+
+    return fields
+
+
 def maxlen(attr):
     """
     Return the maximum length for the given attribute.
