@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -369,6 +369,35 @@ class sendmail_failure(Email):
         }
 
 
+class trainwreck_problems_current_needs_pruning(ProblemReportEmail):
+    """
+    Problem report to indicate if the "current" Trainwreck DB is in
+    need of pruning (if rotation is used).
+    """
+    default_subject = "Trainwreck DB needs pruning"
+    abstract = False
+
+    def sample_data(self, request):
+        return {
+            'problems': [(42, datetime.date(2021, 1, 1))],
+        }
+
+
+class trainwreck_problems_missing_dbs(ProblemReportEmail):
+    """
+    Problem report to ensure next year's Trainwreck DB exists, before
+    it's actually needed.
+    """
+    default_subject = "Trainwreck missing DB"
+    abstract = False
+
+    def sample_data(self, request):
+        next_year = six.text_type(self.app.today().year + 1)
+        return {
+            'problems': [next_year],
+        }
+
+
 class upgrade_failure(Email):
     """
     Sent when an app upgrade is attempted, but ultimately failed.
