@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -134,7 +134,7 @@ def get_daemon(config, pidfile=None):
     return FileMonitorDaemon(pidfile, config=config)
 
 
-def start_daemon(config, pidfile=None, daemonize=True):
+def start_daemon(config, pidfile=None, daemonize=False):
     """
     Start the file monitor daemon.
     """
