@@ -26,6 +26,7 @@ Problem Report Handlers
 
 from __future__ import unicode_literals, absolute_import
 
+import calendar
 import logging
 
 from rattail.db import Session
@@ -119,6 +120,73 @@ class ProblemReportHandler(object):
                                        system_key, problem_key))
             return reports[0]
 
+    def normalize_problem_report(self, report,
+                                 include_schedule=False,
+                                 include_recipients=False,
+                                 **kwargs):
+        """
+        Return a normalized data dictionary for the given problem
+        report.
+
+        :param include_schedule: If true, data dict will include the
+           ``enabled`` field, as well as the ``day0`` thru ``day6``
+           flag fields.
+
+        :param include_recipients: If true, data dict will include the
+           ``email_recipients`` field, which is a list of email
+           addresses.
+        """
+        data = {
+            'system_key': report.system_key,
+            'problem_key': report.problem_key,
+            'problem_title': report.problem_title,
+            'description': (report.__doc__ or '').strip() or None,
+            'email_key': self.get_email_key(report),
+        }
+
+        if include_schedule:
+            data['enabled'] = self.is_enabled(report)
+            data['days'] = {}
+            for day in range(7):
+                daykey = 'day{}'.format(day)
+                data[daykey] = self.should_run_for_day(report, day)
+                data['days'][daykey] = data[daykey]
+
+        if include_recipients:
+            email_handler = self.app.get_email_handler()
+            email = email_handler.get_email(data['email_key'])
+            data['email_recipients'] = email.get_recips('all')
+
+        return data
+
+    def is_enabled(self, report):
+        """
+        Returns boolean indicating if the given problem report is
+        enabled.
+        """
+        key = '{}.{}'.format(report.system_key, report.problem_key)
+        enabled = self.config.getbool('rattail.problems',
+                                      '{}.enabled'.format(key))
+        if enabled is not None:
+            return enabled
+        return True
+
+    def should_run_for_day(self, report, day):
+        """
+        Returns boolean indicating if the given problem report should
+        be ran for the given weekday.
+
+        :param day: Integer corresponding to a particular weekday.
+           Uses the same conventions as Python itself, i.e. Monday is
+           represented as zero (0).
+        """
+        key = '{}.{}'.format(report.system_key, report.problem_key)
+        enabled = self.config.getbool('rattail.problems',
+                                      '{}.day{}'.format(key, day))
+        if enabled is not None:
+            return enabled
+        return True
+
     def organize_problem_reports(self, reports):
         """
         Returns a nested dict with the given problem reports.
@@ -139,7 +207,7 @@ class ProblemReportHandler(object):
         problem_reports = self.get_all_problem_reports()
         return sorted(set([pr.system_key for pr in problem_reports]))
 
-    def run_problem_reports(self, reports, fix=False):
+    def run_problem_reports(self, reports, fix=False, force=False, **kwargs):
         """
         Run the given set of problem reports.
 
@@ -151,16 +219,34 @@ class ProblemReportHandler(object):
             system = organized[system_key]
             for problem_key in sorted(system):
                 report = system[problem_key]
-                self.run_problem_report(report, fix=fix)
+                self.run_problem_report(report, fix=fix, force=force)
 
     def run_problem_report(self, problem_report, fix=False,
-                           send=True, **kwargs):
+                           send=True, force=False, **kwargs):
         """
-        Run a specific problem report.
+        Run the given problem report, if it is enabled and scheduled
+        to run for the current day.
+
+        :param force: If true, the report will run regardless of
+           whether it is enabled at all / for the current day.  If
+           false (the default) then the report's enabled flags will
+           determine whether we should actually run it now.
         """
-        log.info("running problem report: %s.%s",
-                 problem_report.system_key,
-                 problem_report.problem_key)
+        key = '{}.{}'.format(problem_report.system_key,
+                             problem_report.problem_key)
+        log.info("running problem report: %s", key)
+
+        if not self.is_enabled(problem_report):
+            log.debug("problem report is not enabled: %s", key)
+            if not force:
+                return
+
+        weekday = self.app.today().weekday()
+        if not self.should_run_for_day(problem_report, weekday):
+            log.debug("problem report is not scheduled for %s: %s",
+                      calendar.day_name[weekday], key)
+            if not force:
+                return
 
         progress = kwargs.pop('progress', self.progress)
         report = problem_report(self.config,
