@@ -699,16 +699,44 @@ class ProductsHandler(GenericHandler, MergeMixin):
                 })
             data['costs'] = costs
 
-        sale_fields = [
-            'sale_price',
-            'sale_price_display',
-            'sale_ends',
-            'sale_ends_display',
-        ]
-        if any([f in fields for f in sale_fields]):
-            sale_price = None
-            if not product.not_for_sale:
-                sale_price = product.current_price
+        if not product.not_for_sale:
+
+            margin_fields = [
+                'true_margin',
+                'true_margin_display',
+            ]
+            if any([f in fields for f in margin_fields]):
+                if product.volatile:
+                    data['true_margin'] = product.volatile.true_margin
+                    data['true_margin_display'] = self.app.render_percent(
+                        product.volatile.true_margin, places=2)
+
+            current_fields = [
+                'current_price',
+                'current_price_display',
+                'current_ends',
+                'current_ends_display',
+            ]
+            if any([f in fields for f in current_fields]):
+                current_price = product.current_price
+                if current_price:
+                    if current_price.price:
+                        data['current_price'] = float(current_price.price)
+                    data['current_price_display'] = self.render_price(current_price)
+                    current_ends = current_price.ends
+                    if current_ends:
+                        current_ends = self.app.localtime(current_ends, from_utc=True).date()
+                        data['current_ends'] = six.text_type(current_ends)
+                        data['current_ends_display'] = self.app.render_date(current_ends)
+
+            sale_fields = [
+                'sale_price',
+                'sale_price_display',
+                'sale_ends',
+                'sale_ends_display',
+            ]
+            if any([f in fields for f in sale_fields]):
+                sale_price = product.sale_price
                 if sale_price:
                     if sale_price.price:
                         data['sale_price'] = float(sale_price.price)
@@ -719,6 +747,24 @@ class ProductsHandler(GenericHandler, MergeMixin):
                         data['sale_ends'] = six.text_type(sale_ends)
                         data['sale_ends_display'] = self.app.render_date(sale_ends)
 
+            tpr_fields = [
+                'tpr_price',
+                'tpr_price_display',
+                'tpr_ends',
+                'tpr_ends_display',
+            ]
+            if any([f in fields for f in tpr_fields]):
+                tpr_price = product.tpr_price
+                if tpr_price:
+                    if tpr_price.price:
+                        data['tpr_price'] = float(tpr_price.price)
+                    data['tpr_price_display'] = self.render_price(tpr_price)
+                    tpr_ends = tpr_price.ends
+                    if tpr_ends:
+                        tpr_ends = self.app.localtime(tpr_ends, from_utc=True).date()
+                        data['tpr_ends'] = six.text_type(tpr_ends)
+                        data['tpr_ends_display'] = self.app.render_date(tpr_ends)
+
         if 'case_quantity' in fields:
             data['case_quantity'] = self.app.render_quantity(
                 self.get_case_size(product))
