@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -147,6 +147,9 @@ class ProjectHandler(object):
                 options['studly_name'] = ''.join([word.capitalize()
                                                   for word in words])
 
+            if 'app_class_prefix' not in options:
+                options['app_class_prefix'] = options['studly_name']
+
             if 'env_name' not in options:
                 options['env_name'] = slug
 
@@ -330,27 +333,6 @@ class RattailProjectHandler(ProjectHandler):
         self.generate('rattail/package/commands.py.mako', os.path.join(package, 'commands.py'),
                       **context)
 
-        self.generate('rattail/package/emails.py.mako', os.path.join(package, 'emails.py'),
-                      **context)
-
-        ##############################
-        # data dir
-        ##############################
-
-        data = os.path.join(package, 'data')
-        os.makedirs(data)
-
-        config = os.path.join(data, 'config')
-        os.makedirs(config)
-
-        self.generate('rattail/package/data/config/rattail.conf.mako',
-                      os.path.join(config, '{}-rattail.conf'.format(slug)),
-                      **context)
-
-        self.generate('rattail/package/data/config/web.conf.mako',
-                      os.path.join(config, '{}-web.conf'.format(slug)),
-                      **context)
-
         ##############################
         # db package dir
         ##############################
@@ -372,9 +354,6 @@ class RattailProjectHandler(ProjectHandler):
             self.generate('rattail/package/db/model/__init__.py.mako', os.path.join(model, '__init__.py'),
                           **context)
 
-            self.generate('rattail/package/db/model/core.py.mako', os.path.join(model, 'core.py'),
-                          **context)
-
             ####################
             # alembic
             ####################
@@ -382,6 +361,7 @@ class RattailProjectHandler(ProjectHandler):
             alembic = os.path.join(db, 'alembic')
             os.makedirs(alembic)
 
+            # TODO: can we get rid of this? why not?
             self.generate('rattail/package/db/alembic/env.py.mako', os.path.join(alembic, 'env.py'),
                           **context)
 
@@ -475,25 +455,6 @@ class RattailProjectHandler(ProjectHandler):
             self.generate('rattail/package/web/views/common.py.mako', os.path.join(views, 'common.py'),
                           **context)
 
-        ##############################
-        # dev
-        ##############################
-
-        dev = os.path.join(path, 'dev')
-        os.makedirs(dev)
-
-        self.generate('rattail/dev/bootstrap.py.mako', os.path.join(dev, 'bootstrap.py'),
-                      **context)
-
-        self.generate('rattail/dev/tasks.py.mako', os.path.join(dev, 'tasks.py'),
-                      **context)
-
-        self.generate('rattail/dev/rattail.conf.mako', os.path.join(dev, 'rattail.conf'),
-                      **context)
-
-        self.generate('rattail/dev/web.conf.mako', os.path.join(dev, 'web.conf'),
-                      **context)
-
         ##############################
         # fablib / machines
         ##############################
